## Vagrant

The following will create Stumpf in a virtual machine and serve the api
from locally on port 5000.
```
vagrant up
vagrant ssh
cd /vagrant
flask run --host 0.0.0.0
```

Note: If you run into issues with the database appearing out of sync, you may
have to migrate the database.  Do this by running `flask db upgrade`. If this
doesn't work, note that you can drop the database and reprovision at any time
by running the following commands:
```
psql -U postgres -h localhost -c 'drop database stumpf'  # inside the VM
vagrant provision  # outside the VM
```

Test the server by running the following in a new terminal.
```
curl http://localhost:5000/api/v1/video
```

This will return a json list of videos or `[]` if none have been imported yet.

## Web client

For development of the web application, we use webpack-dev-server with a proxy to
api server (defaults to localhost:5000).  You can run this server outside of the
virtual machine.  First, ensure you have a recent version of node installed
(>= 8 recommended).

```
# install yarn globally
npm install -g yarn

# go to the web directory and install dependencies
yarn

# set an environment variable telling the dev server where to proxy
# api requests (defaults to localhost:5000)
export STUMPF_API=http://localhost:5000

# run the development server
yarn dev
```

## OAuth for local development

Note: You can skip this section if you just want to use the default mocked
interface for OAuth.

For authentication to work, you must set environment variables required for oauth
session negotiation.
```
GOOGLE_OAUTH_CLIENT_ID
GOOGLE_OAUTH_CLIENT_SECRET
```
These values for the deployed application can be found in vault under
`secret/projects/diva-mturk/stumpf/oauth`.  Developers can generate a new oauth
application at  <https://console.developers.google.com/apis/credentials/oauthclient/>
You should set the origin to local host/port created by webpack-dev-server
(<http://localhost:8080> by default).  The redirect path for stumpf is at `/auth/google/authorized`
(e.g. <http://localhost:8080/auth/google/authorized>).

