"""
Move video relationship from assignment to task

Revision ID: 3b6bd99d3420
Revises: 20368da7e9b8
Create Date: 2018-05-21 15:41:13.604873

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = '3b6bd99d3420'
down_revision = '20368da7e9b8'
branch_labels = None
depends_on = None


def upgrade():
    # First add column as nullable=True so we can perform update in place
    op.add_column('task', sa.Column('video_id', postgresql.UUID(), nullable=True))
    op.create_foreign_key(op.f('fk_task_video_id_video'), 'task', 'video', ['video_id'], ['id'])

    # Store video_id for assignments on the task table
    # This only picks the first video_id from an assignment and places it on the task
    op.execute('UPDATE task t SET video_id = a.video_id FROM assignment a WHERE t.id = a.task_id')

    # Now set nullable=False since we populated the field
    op.alter_column('task', 'video_id', nullable=False)

    # Drop the video_id from the assignments (since they're now stored via task)
    op.drop_constraint('assignment_video_id_fkey', 'assignment', type_='foreignkey')
    op.drop_column('assignment', 'video_id')


def downgrade():
    op.add_column('assignment', sa.Column('video_id', postgresql.UUID(), autoincrement=False,
                                          nullable=True))
    op.create_foreign_key('assignment_video_id_fkey', 'assignment', 'video', ['video_id'], ['id'])

    # Add the video id from the task to every assignment
    op.execute('UPDATE assignment a SET video_id = t.video_id FROM task t WHERE t.id = a.task_id')

    # Now set nullable=False since we populated the field
    op.alter_column('assignment', 'video_id', nullable=False)

    op.drop_constraint(op.f('fk_task_video_id_video'), 'task', type_='foreignkey')
    op.drop_column('task', 'video_id')
