"""
Add OAuth and User models

Revision ID: 810b2e795161
Revises: 3c06fb7273cc
Create Date: 2018-06-06 09:05:01.617296

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = '810b2e795161'
down_revision = '3c06fb7273cc'
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        'user',
        sa.Column('id', postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column('created', sa.DateTime(), nullable=False),
        sa.Column('email', sa.String(), nullable=False),
        sa.PrimaryKeyConstraint('id', name=op.f('pk_user')),
        sa.UniqueConstraint('email', name=op.f('uq_user_email'))
    )
    op.create_table(
        'flask_dance_oauth',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('provider', sa.String(length=50), nullable=True),
        sa.Column('created_at', sa.DateTime(), nullable=True),
        sa.Column('token', sa.types.JSON(), nullable=True),
        sa.Column('provider_user_id', sa.String(length=256), nullable=True),
        sa.Column('user_id', postgresql.UUID(as_uuid=True), nullable=True),
        sa.ForeignKeyConstraint(
            ['user_id'], ['user.id'], name=op.f('fk_flask_dance_oauth_user_id_user')),
        sa.PrimaryKeyConstraint('id', name=op.f('pk_flask_dance_oauth')),
        sa.UniqueConstraint('provider_user_id', name=op.f('uq_flask_dance_oauth_provider_user_id'))
    )
    op.create_table(
        'token',
        sa.Column('id', postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column('user_id', postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column('created', sa.DateTime(), nullable=False),
        sa.Column('expires', sa.DateTime(), nullable=False),
        sa.Column('token', sa.String(), nullable=False),
        sa.ForeignKeyConstraint(['user_id'], ['user.id'], name='token_user_id_fkey'),
        sa.PrimaryKeyConstraint('id', name=op.f('pk_token')),
        sa.UniqueConstraint('token', name=op.f('uq_token_token'))
    )


def downgrade():
    op.drop_table('token')
    op.drop_table('flask_dance_oauth')
    op.drop_table('user')
