"""
Update task table to accomodate hits/kwits

Revision ID: c26fdd4faace
Revises: 04e3157c399c
Create Date: 2018-06-07 10:05:24.073944

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'c26fdd4faace'
down_revision = '04e3157c399c'
branch_labels = None
depends_on = None


def upgrade():
    postgresql.ENUM('HIT', 'KWIT', name='hit_kwit_enum').create(op.get_bind())
    postgresql.ENUM('NotReviewed', 'MarkedForReview', 'ReviewedAppropriate',
                    'ReviewedInappropriate', name='task_review_status_enum').create(op.get_bind())
    postgresql.ENUM('Assignable', 'Unassignable', 'Reviewable', 'Reviewing', 'Disposed',
                    name='task_status_enum').create(op.get_bind())

    op.drop_column('task', 'type_')
    op.add_column('task', sa.Column('type_', postgresql.ENUM('HIT', 'KWIT', name='hit_kwit_enum'),
                                    nullable=False))

    op.add_column('task', sa.Column('title', sa.String(), nullable=True))
    op.execute('UPDATE task SET title = name')
    op.alter_column('task', 'title', nullable=False)

    op.add_column('task', sa.Column('description', sa.String(), nullable=True))
    op.add_column('task', sa.Column('hit_id', sa.String(), nullable=True))
    op.add_column('task', sa.Column('keywords', sa.String(), nullable=True))
    op.add_column('task', sa.Column('max_assignments', sa.Integer(), nullable=False))
    op.add_column('task',
                  sa.Column('review_status',
                            postgresql.ENUM('NotReviewed', 'MarkedForReview',
                                            'ReviewedAppropriate', 'ReviewedInappropriate',
                                            name='task_review_status_enum'), nullable=False))
    op.add_column('task',
                  sa.Column('status', postgresql.ENUM('Assignable', 'Unassignable',
                                                      'Reviewable', 'Reviewing', 'Disposed',
                                                      name='task_status_enum'), nullable=False))
    op.add_column('task', sa.Column('reward', sa.Integer(), nullable=True))

    op.drop_constraint('uq_task_name', 'task', type_='unique')
    op.drop_column('task', 'name')

    # assignment changes
    postgresql.ENUM('Abandoned', 'Returned', 'Accepted', 'Submitted', 'Approved',
                    'Rejected', name='assignment_status_enum').create(op.get_bind())
    op.add_column('assignment', sa.Column('abandoned_time', sa.DateTime(), nullable=True))
    op.add_column('assignment', sa.Column('accepted_time', sa.DateTime(), nullable=True))
    op.add_column('assignment', sa.Column('approved_time', sa.DateTime(), nullable=True))
    op.add_column('assignment', sa.Column('assignment_id', sa.String(), nullable=True))
    op.add_column('assignment', sa.Column('rejected_time', sa.DateTime(), nullable=True))
    op.add_column('assignment', sa.Column('returned_time', sa.DateTime(), nullable=True))
    op.add_column('assignment',
                  sa.Column('status', postgresql.ENUM('Abandoned', 'Returned', 'Accepted',
                                                      'Submitted', 'Approved', 'Rejected',
                                                      name='assignment_status_enum'),
                            nullable=False))
    op.add_column('assignment', sa.Column('submitted_time', sa.DateTime(), nullable=True))
    op.add_column('assignment', sa.Column('worker_id', sa.String(), nullable=True))
    op.drop_column('assignment', 'completed')


def downgrade():
    op.add_column('task', sa.Column('name', sa.VARCHAR(), autoincrement=False, nullable=True))
    op.execute('UPDATE task SET name = title')
    op.alter_column('task', 'name', nullable=False)
    op.create_unique_constraint('uq_task_name', 'task', ['name'])

    op.execute(f'ALTER TABLE task ALTER COLUMN type_ TYPE {sa.String()}')

    op.drop_column('task', 'title')
    op.drop_column('task', 'status')
    op.drop_column('task', 'review_status')
    op.drop_column('task', 'max_assignments')
    op.drop_column('task', 'keywords')
    op.drop_column('task', 'hit_id')
    op.drop_column('task', 'description')
    op.drop_column('task', 'reward')
    op.execute('DROP TYPE hit_kwit_enum;')
    op.execute('DROP TYPE task_review_status_enum;')
    op.execute('DROP TYPE task_status_enum;')

    op.add_column('assignment', sa.Column('completed', postgresql.TIMESTAMP(), autoincrement=False,
                                          nullable=True))
    op.drop_column('assignment', 'worker_id')
    op.drop_column('assignment', 'submitted_time')
    op.drop_column('assignment', 'status')
    op.drop_column('assignment', 'returned_time')
    op.drop_column('assignment', 'rejected_time')
    op.drop_column('assignment', 'assignment_id')
    op.drop_column('assignment', 'approved_time')
    op.drop_column('assignment', 'accepted_time')
    op.drop_column('assignment', 'abandoned_time')
    op.execute('DROP TYPE assignment_status_enum;')
