import random

import click

from stumpf.app import create_app
from stumpf.fakes import fake
from stumpf.models import db, Video


@click.command()
@click.option('--only-if-empty', type=click.BOOL, default=False, is_flag=True,
              help='Only generate data if the DB is empty (defaults to false).')
@click.option('--small', type=click.BOOL, default=False, is_flag=True,
              help='Generate a minimal amount of data for testing.')
def sample_data(only_if_empty, small):
    """
    Management script for sample data generation.
    """
    app = create_app({})

    grouper_app = {
        'repo_url': 'https://github.com/Kitware/vaui',
        'name': 'Grouper',
        'url': 'https://mturk.kitware.com/grouper'}
    refiner_app = {
        'repo_url': 'https://github.com/Kitware/refiner',
        'name': 'Refiner',
        'url': 'https://mturk.kitware.com/refiner'}

    with app.app_context():
        if only_if_empty and Video.query.first() is not None:
            return

        fake_users = [fake.stumpf_user() for _ in range(25)]
        db.session.add_all(fake_users)
        db.session.commit()

        # Make sure we have a few repeats of url/repo/name
        annotation_apps = [
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**grouper_app),
            fake.stumpf_annotation_app(**refiner_app),
            fake.stumpf_annotation_app(**refiner_app)]
        annotation_apps.extend([fake.stumpf_annotation_app() for _ in range(4)])

        try:
            for ann_app in annotation_apps:
                db.session.add(ann_app)
                db.session.commit()
                for _ in range(10 if small else 1000):
                    video = fake.stumpf_video()
                    db.session.add(video)
                    db.session.commit()

                    for _ in range(10):
                        task = fake.stumpf_task(video.id, ann_app.id, random.choice(fake_users).id)
                        db.session.add(task)
                        db.session.commit()

                        db.session.add_all([fake.stumpf_assignment(task.id) for _ in range(3)])
                        db.session.commit()
                db.session.commit()

        except Exception:
            click.echo('Failed to generate random videos', err=True)
            raise


@click.command()
def create_tables():
    app = create_app({})

    with app.app_context():
        db.create_all()
