from datetime import datetime, timedelta
import os
import secrets
import string

from faker import Faker
from faker.providers import BaseProvider

from stumpf.models import AnnotationApp, Assignment, Task, User, Video

fake = Faker()
alphabet = string.ascii_uppercase + string.digits


class StumpfProvider(BaseProvider):
    def stumpf_user(self):
        return User(email=self.generator.email(domain='kitware.com'))

    def stumpf_video(self):
        path = os.path.dirname(self.generator.file_path(depth=5))
        name = '%s_%s' % (self.generator.random_int(max=999999),
                          self.generator.file_name(category='video'))

        frame_rate = self.generator.random_element(['30', '60', '29.97', '23.976', '24'])
        duration = self.generator.random_int(max=999999, min=1) / float(frame_rate)
        return Video(**{
            'path': f's3:/%s/%s' % (path, name),
            'name': name,
            'frame_rate': frame_rate,
            'duration': duration,
            'width': self.generator.random_element([1280,
                                                    1440,
                                                    1920,
                                                    1024,
                                                    3840,
                                                    1600]),
            'height': self.generator.random_element([800,
                                                     900,
                                                     1200,
                                                     576,
                                                     2160])
        })

    def stumpf_task(self, video_id, annotation_app_id, user_id):
        return Task(**{
            'video_id': video_id,
            'annotation_app_id': annotation_app_id,
            'user_id': user_id,
            'hit_id': self.generator.uuid4(),
            'type_': self.generator.random_element({
                'HIT': 0.95,
                'KWIT': 0.05
            }),
            'title': f'{self.generator.word()} Video annotation',
            'description': self.generator.paragraph(),
            'keywords': ','.join(self.generator.words(nb=5)),
            'status': self.generator.random_element(['Assignable', 'Unassignable', 'Reviewable',
                                                     'Reviewing', 'Disposed']),
            'review_status': self.generator.random_element(
                ['NotReviewed', 'MarkedForReview', 'ReviewedAppropriate', 'ReviewedInappropriate']),
            'max_assignments': self.generator.random_int(min=1, max=5),
            'reward': self.generator.random_int(min=10, max=200),
            'args': self.generator.simple_profile()
        })

    def stumpf_assignment(self, task_id):
        task = Task.query.get(task_id)
        assignment_kwargs = {}

        if task.type_ == 'HIT':
            assignment_kwargs.update({
                'assignment_id': ''.join(secrets.choice(alphabet) for i in range(30)),
                'worker_id': ''.join(secrets.choice(alphabet) for i in range(14))
            })

        assignment_kwargs['status'] = self.generator.random_element(
            ['Abandoned', 'Returned', 'Accepted', 'Submitted', 'Approved', 'Rejected'])

        assignment_kwargs['accepted_time'] = datetime.utcnow()

        if assignment_kwargs['status'] == 'Abandoned':
            assignment_kwargs['abandoned_time'] = (assignment_kwargs['accepted_time'] +
                                                   timedelta(minutes=1))
        elif assignment_kwargs['status'] == 'Returned':
            assignment_kwargs['returned_time'] = (assignment_kwargs['accepted_time'] +
                                                  timedelta(minutes=1))
        elif assignment_kwargs['status'] == 'Submitted':
            assignment_kwargs['submitted_time'] = (assignment_kwargs['accepted_time'] +
                                                   timedelta(minutes=1))
        elif assignment_kwargs['status'] == 'Approved':
            assignment_kwargs['submitted_time'] = (assignment_kwargs['accepted_time'] +
                                                   timedelta(minutes=1))
            assignment_kwargs['approved_time'] = (assignment_kwargs['submitted_time'] +
                                                  timedelta(hours=2))
        elif assignment_kwargs['status'] == 'Rejected':
            assignment_kwargs['submitted_time'] = (assignment_kwargs['accepted_time'] +
                                                   timedelta(minutes=1))
            assignment_kwargs['rejected_time'] = (assignment_kwargs['submitted_time'] +
                                                  timedelta(hours=2))

        return Assignment(task_id=task_id, **assignment_kwargs)

    def stumpf_annotation_app(self, repo_url=None, hash_=None, name=None, url=None):
        return AnnotationApp(**{
            'repo_url': repo_url if repo_url is not None else self.generator.url(),
            'hash': hash_ if hash_ is not None else self.generator.sha1(),
            'name': name if name is not None else f'{self.generator.last_name()} App',
            'url': url if url is not None else self.generator.url()
        })


fake.add_provider(StumpfProvider)
