import re

from raven.processors import SanitizePasswordsProcessor


class SanitizeProcessor(SanitizePasswordsProcessor):
    # Extend the default keys to include our own, these are case sensitive
    KEYS = frozenset([
        'password',
        'secret',
        'passwd',
        'authorization',
        'api_key',
        'apikey',
        'sentry_dsn',
        'access_token',
        'SQLALCHEMY_DATABASE_URI',
        'STUMPF_POSTGRES_URI',
        'X_STUMPF_TOKEN',
        'SECRET_KEY',
        'GOOGLE_OAUTH_CLIENT_SECRET'
    ])

    VALUE_REGEXES = [re.compile(r'^(\'|")[a-f0-9]{64}(\'|")$'),  # tokens (secrets.token_hex)
                     re.compile(r'^(\'|")postgresql://(\'|")$')]  # connection URIs

    def sanitize(self, item, value):
        value = super(SanitizePasswordsProcessor, self).sanitize(item, value)

        if isinstance(value, str) and any([regex.match(value) for regex in self.VALUE_REGEXES]):
            return self.MASK

        return value
