from flask import request
from werkzeug.exceptions import BadRequest


def boolean(value: str) -> bool:
    """Convert a string into a boolean value.

    Largely copied from flask-restful (inputs.boolean).
    """
    if not value:
        raise BadRequest('The parameter "desc" must not be empty.')
    value = value.lower()
    if value in ('true', '1'):
        return True
    if value in ('false', '0'):
        return False
    raise BadRequest('Invalid value for "desc".  Accepts "true" or "false".')


def sorted_query(model, query=None):
    """
    Return a sorted query from the provided model.

    This method assumes that the model passed in contains the following extra
    fields:
     * sortable_fields: (dict) A mapping from field name => column
     * default_sort: (str) The default sorting field
     * default_desc: (bool) The default order (desc = descending order)

    :param model: The sqlachemy model definition
    :param query: The query to sort (defaults to model.query)
    """
    query = query or model.query

    sort = request.args.get('sort', model.default_sort, str)
    desc = request.args.get('desc', model.default_desc, boolean)

    if sort not in model.sortable_fields:
        raise BadRequest('Invalid sort field')

    if desc:
        query = query.order_by(model.sortable_fields[sort].desc())
    else:
        query = query.order_by(model.sortable_fields[sort])
    return query
