from flask import Blueprint, jsonify, request

from stumpf.models import AnnotationApp, AnnotationAppSchema, db
from stumpf.pagination import paginated_response
from stumpf.sorting import sorted_query


annotation_app_bp = Blueprint('annotation_app', __name__)

annotation_app_schema = AnnotationAppSchema()


@annotation_app_bp.route('/annotation-app', methods=['POST'])
def create_annotation_app():
    try:
        annotation_app = annotation_app_schema.load(request.json)

        if AnnotationApp.query.filter_by(name=annotation_app.name,
                                         repo_url=annotation_app.repo_url,
                                         url=annotation_app.url,
                                         hash=annotation_app.hash).first():
            return jsonify({
                'error': 'Annotation app already exists'
            }), 409

        db.session.add(annotation_app)
        db.session.commit()
        return jsonify(annotation_app_schema.dump(annotation_app)), 201
    except Exception as e:
        db.session.rollback()
        raise


@annotation_app_bp.route('/annotation-app', methods=['GET'])
def list_annotation_app():
    query = sorted_query(AnnotationApp)
    return paginated_response(query, lambda items: annotation_app_schema.dump(items, many=True))


@annotation_app_bp.route('/annotation-app/<uuid:annotation_app_id>', methods=['GET'])
def get_annotation_app(annotation_app_id):
    annotation_app = AnnotationApp.query.get_or_404(annotation_app_id)
    return jsonify(annotation_app_schema.dump(annotation_app))


@annotation_app_bp.route('/annotation-app/<uuid:annotation_app_id>', methods=['DELETE'])
def delete_annotation_app(annotation_app_id):
    try:
        AnnotationApp.query.filter_by(id=annotation_app_id).delete()
        db.session.commit()
        return '', 204

    except Exception as e:
        db.session.rollback()
        raise
