from flask import Blueprint, jsonify, request

from stumpf.models import Artifact, ArtifactSchema, Assignment, db
from stumpf.pagination import paginated_response
from stumpf.sorting import sorted_query


artifact_bp = Blueprint('artifact', __name__)
artifact_schema = ArtifactSchema()


@artifact_bp.route('/artifact', methods=['POST'])
def create_artifact():
    try:
        artifact = artifact_schema.load(request.json)
        assignment = Assignment.query.get(artifact.assignment_id)

        if Artifact.query.filter_by(path=artifact.path).first():
            return jsonify({
                'error': 'Artifact with that path already exists'
            }), 409
        elif not assignment:
            return jsonify({
                'error': 'Assignment does not exist'
            }), 400
        elif assignment.completed is not None:
            return jsonify({
                'error': 'Assignment has already been completed'
            }), 409

        db.session.add(artifact)
        db.session.commit()
        return jsonify(artifact_schema.dump(artifact)), 201
    except Exception as e:
        db.session.rollback()
        raise

    return jsonify(artifact_schema.dump(artifact))


@artifact_bp.route('/artifact/<uuid:assignment_id>', methods=['GET'])
def list_artifacts(assignment_id):
    Assignment.query.get_or_404(assignment_id)
    query = Artifact.query.filter_by(assignment_id=assignment_id)
    query = sorted_query(Artifact, query=query)
    return paginated_response(query, lambda items: artifact_schema.dump(items, many=True))
