from flask import Blueprint, jsonify, request

from stumpf.models import Assignment, AssignmentSchema, db, Task, Video
from stumpf.pagination import paginated_response
from stumpf.sorting import sorted_query


assignment_bp = Blueprint('assignment', __name__)
assignment_schema = AssignmentSchema()


@assignment_bp.route('/assignment', methods=['GET'])
def list_assignments():
    query = sorted_query(Assignment)
    return paginated_response(query, lambda items: assignment_schema.dump(items, many=True))


@assignment_bp.route('/assignment', methods=['POST'])
def create_assignment():
    try:
        assignment = assignment_schema.load(request.json)

        if not Task.query.get(assignment.task_id):
            return jsonify({
                'error': 'No such task.'
            }), 400
        elif not Video.query.get(assignment.video_id):
            return jsonify({
                'error': 'No such video.'
            }), 400

        db.session.add(assignment)
        db.session.commit()
        return jsonify(assignment_schema.dump(assignment)), 201
    except Exception as e:
        db.session.rollback()
        raise

    return jsonify(assignment_schema.dump(assignment))


# todo put vs patch
@assignment_bp.route('/assignment/<uuid:assignment_id>', methods=['PUT'])
def update_assignment(assignment_id):
    assignment = Assignment.query.get_or_404(assignment_id)

    if assignment.completed is not None:
        return jsonify({
            'error': 'Assignment is already completed'
        }), 409

    try:
        assignment_update_attrs = assignment_schema.load(request.json, only=('completed',))

        for attr, value in assignment_update_attrs.items():
            setattr(assignment, attr, value)

        db.session.add(assignment)
        db.session.commit()
        return jsonify(assignment_schema.dump(assignment)), 201
    except Exception as e:
        db.session.rollback()
        raise

    return jsonify(assignment_schema.dump(assignment))
