from flask import Blueprint, jsonify, request
from flask_login import current_user

from stumpf.models import db, Token, TokenSchema


token_bp = Blueprint('token', __name__)

token_schema = TokenSchema()


@token_bp.route('/token', methods=['POST'])
def create_token():
    token_json = request.json
    token_json['user_id'] = current_user.get_id()
    token = token_schema.load(token_json)
    db.session.add(token)
    db.session.commit()
    return jsonify(token_schema.dump(token))


@token_bp.route('/token/<token_value>')
def get_token(token_value):
    token = Token.query.filter_by(token=token_value).first_or_404()
    return jsonify(token_schema.dump(token))


@token_bp.route('/token/<token_value>', methods=['DELETE'])
def delete_token(token_value):
    token = Token.query.filter_by(token=token_value).first_or_404()
    db.session.delete(token)
    db.session.commit()
    return '', 204
