from flask import Blueprint, jsonify, request

from stumpf.models import db, Task, TaskSchema, Video, VideoSchema
from stumpf.pagination import paginated_response
from stumpf.sorting import sorted_query


video_bp = Blueprint('video', __name__)
video_schema = VideoSchema()
task_schema = TaskSchema()


@video_bp.route('/video', methods=['POST'])
def create_video():
    try:
        video = video_schema.load(request.json)

        if Video.query.filter_by(path=video.path).first():
            return jsonify({
                'error': 'Video path already exists'
            }), 409
        elif Video.query.filter_by(name=video.name).first():
            return jsonify({
                'error': 'Video name already exists'
            }), 409

        db.session.add(video)
        db.session.commit()
        return jsonify(video_schema.dump(video)), 201
    except Exception as e:
        db.session.rollback()
        raise

    return jsonify(video_schema.dump(video))


@video_bp.route('/video', methods=['GET'])
def list_videos():
    query = sorted_query(Video)
    return paginated_response(query, lambda items: video_schema.dump(items, many=True))


@video_bp.route('/video/<uuid:video_id>', methods=['GET'])
def get_video(video_id):
    video = Video.query.get_or_404(video_id)
    return jsonify(video_schema.dump(video))


@video_bp.route('/video/<uuid:video_id>/tasks', methods=['GET'])
def list_video_tasks(video_id):
    video = Video.query.get_or_404(video_id)
    query = sorted_query(Task, Task.query.filter_by(video=video))
    return paginated_response(query, lambda items: task_schema.dump(items, many=True))
