import json
import re
from urllib.parse import urlparse

from flask import Blueprint, current_app, request

from stumpf.decorators import public_endpoint
from stumpf.mturk_utils import (handle_mturk_assignment_event, handle_mturk_hit_event,
                                verify_signature)


webhook_bp = Blueprint('webhook', __name__)


@webhook_bp.route('/mturk-notification', methods=['POST'])
@public_endpoint
def handle_mturk_notification():
    data = json.loads(request.data)
    message = json.loads(data['Message'])
    failed = False

    current_app.logger.info(data)

    if not re.match(r'^sns\..*\.amazonaws\.com$', urlparse(data['SigningCertURL']).netloc):
        current_app.logger.warning(
            f'SNS cert url belongs to unknown source, url: {data["SigningCertURL"]}')
    elif not verify_signature(data):
        current_app.logger.warning('Unable to verify signature for data', data)
        return '', 400

    for event in message['Events']:
        if event['EventType'] == 'Ping':
            continue

        try:
            if event['EventType'].startswith('Assignment'):
                handle_mturk_assignment_event(event)
            elif event['EventType'].startswith('HIT'):
                handle_mturk_hit_event(event)
            else:
                current_app.logger.warning('Received unknown event type', event)
                continue
        except Exception as e:
            current_app.logger.exception(e)
            failed = True

    if failed:
        return '', 500  # signal SNS to retry
    else:
        return '', 200
