import os
from pkg_resources import DistributionNotFound, get_distribution

import click
from requests_toolbelt.sessions import BaseUrlSession

from stumpfwald.artifact import artifact
from stumpfwald.assignment import assignment
from stumpfwald.task import task
from stumpfwald.video import video

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:
    pass



class StumpfwaldSession(BaseUrlSession):
    page_size = 50

    def __init__(self, base_url):
        super(StumpfwaldSession, self).__init__(base_url=base_url)
        self.headers.update({
            'User-agent': 'stumpfwald/%s' % __version__,
            'X-Stumpf-Token': os.getenv('X_STUMPF_TOKEN')
        })


@click.group()
@click.option('--api-url', default='http://localhost:5000/api/v1/', envvar='STUMPF_API_URL')
@click.version_option()
@click.pass_context
def cli(ctx, api_url):
    session = StumpfwaldSession(api_url)
    ctx.obj = {
        'session': session
    }


cli.add_command(artifact)
cli.add_command(assignment)
cli.add_command(task)
cli.add_command(video)
