import json

import click


@click.group(name='assignment', short_help='The assignment resource.')
@click.pass_obj
def assignment(ctx):
    pass


@assignment.command(name='create', help='Create an assignment from a task')
@click.argument('task-id')
@click.argument('video-id')
@click.pass_obj
def create(ctx, task_id, video_id):
    r = ctx['session'].post('assignment', json={
        'task_id': task_id,
        'video_id': video_id
    })

    if not r.ok:
        click.echo(json.dumps(r.json()), err=True)
    else:
        click.echo(json.dumps(r.json()))


@assignment.command(name='complete', help='Mark an assignment as completed')
@click.argument('assignment-id')
@click.pass_obj
def complete(ctx, assignment_id):
    from datetime import datetime
    r = ctx['session'].put(f'assignment/{assignment_id}', json={
        'completed': datetime.utcnow().isoformat()
    })

    if not r.ok:
        click.echo(json.dumps(r.json()), err=True)
    else:
        click.echo(json.dumps(r.json()))


@assignment.command(name='list', help='List assignments')
@click.pass_obj
def list_(ctx):
    r = ctx['session'].get('assignment')

    if not r.ok:
        click.echo(json.dumps(r.json()), err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))
