import json
import os

import click
from MediaInfo import MediaInfo


@click.group(name='video', short_help='The video resource.')
@click.pass_obj
def video(ctx):
    pass


@video.command(name='create', help='Create a video')
@click.argument('path', type=click.Path(dir_okay=False, file_okay=True, exists=True))
@click.option('-f', '--frame-rate', default=29.97, required=True)
@click.option('-l', '--length', default=0.0, required=True,
              help='Length of video in seconds')
@click.option('-w', '--width', required=True)
@click.option('--height', required=True)
@click.option('-d', '--derived-video-id', required=False, type=click.UUID)
@click.pass_obj
def create(ctx, path, frame_rate, length, width, height, derived_video_id):
    data = {
        'name': os.path.basename(path),
        'path': os.path.abspath(path),
        'frame_rate': frame_rate,
        'duration': length,
        'width': width,
        'height': height
    }

    if derived_video_id:
        data['derived_video_id'] = str(derived_video_id)

    r = ctx['session'].post('video', json=data)

    if not r.ok:
        click.echo(json.dumps(r.json()), err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


@video.command(name='import', help='Import a video')
@click.argument('path', nargs=-1, type=click.Path(dir_okay=False, file_okay=True, exists=True))
@click.pass_obj
def import_(ctx, path):
    for path_ in path:
        m = MediaInfo(filename=path_).getInfo()

        r = ctx['session'].post('video', json={
            'name': os.path.basename(path_),
            'path': os.path.abspath(path_),
            'frame_rate': m['videoFrameRate'],
            'duration': m['duration'],
            'width': m['videoWidth'],
            'height': m['videoHeight']
        })

        if not r.ok:
            click.echo(json.dumps(r.json(), indent=4), err=True)
        else:
            click.echo(json.dumps(r.json(), indent=4))


@video.command(name='list', help='List videos')
@click.pass_obj
def list_(ctx):
    r = ctx['session'].get('video')

    if not r.ok:
        click.echo(json.dumps(r.json(), indent=4), err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))
