import axios from 'axios';
import cookies from 'js-cookie';
import Raven from 'raven-js';
import RavenVue from 'raven-js/plugins/vue';
import Vue from 'vue';
import VueAxios from 'vue-axios';
import Vuetify from 'vuetify';
import 'vuetify/dist/vuetify.min.css';

import App from './App';
import router from './router';
import getToken from './token';


const axiosInstance = axios.create({
  baseURL: '/api/v1',
  headers: {
    'X-Stumpf-token': getToken(),
    'Content-Type': 'application/json',
  },
});

Vue.use(VueAxios, axiosInstance);
Vue.use(Vuetify);

function initialize() {
  axiosInstance.get('/user/me').then((resp) => {
    window.App = new Vue({
      el: '#app',
      router,
      components: { App },
      data: {
        user: resp.data,
      },
      template: '<App :user="user"/>',
    });
  }).catch(() => {
    window.location.replace('/login');
  });
}

const sentryDSN = cookies.get('stumpf-sentry-dsn');
if (sentryDSN) {
  const release = `${process.env.GITHASH}`;
  Raven
    .config(sentryDSN, {
      release,
      sanitizeKeys: [/[-_]token$/i, /[-_]sensitive[-_]/i, /[-_]auth[-_]/i, /^session$/],
    })
    .addPlugin(RavenVue, Vue)
    .install();

  Raven.context(initialize);
} else {
  initialize();
}
